<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="no" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Opprett regneark</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Opprett et nytt regneark</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Juster til bunn</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Juster celleinnhold nederst i merkede celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Juster til midten</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Sentrer celleinnhold i merkede celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Venstrejuster</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Venstrejuster innholdet i merkede celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Høyrejuster</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Høyrejuster innholdet i merkede celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Toppjuster</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Toppjuster innholdet i merkede celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Senterjuster vertikalt</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Senterjuster innholdet i de valgte cellene vertikalt</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Eksportere regneark</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Eksporter regnearket til en komma-separert fil</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importer regneark</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importer kommaseparert fil</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Slå sammen celler</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Slå sammen valgte celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Angi alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Angi alias for valgte celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Splitt celler</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Del tidligere sammenslåtte celler</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Fet tekst</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Gjør teksten i valgte celler fet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Kursiv tekst</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Gjør teksten i valgte celler kursiv</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Understreke tekst</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Understrek teksten i valgte celler</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Egendefinert farge</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Slå sammen celler</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Splitt celler</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Sett inn rader</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Fjern rader</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Sett inn kolonner</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Egenskaper for celle</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Farge</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekst</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Bakgrunn</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Justering</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horisontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Venstre</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Midtstill</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Høyre</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Vertikal</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Topp</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Bunn</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stil</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Fet</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Kursiv</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Understreking</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Visningsenhet</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Enhetsstreng</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias for denne cellen</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Alle (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importer fil</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Eksporter fil</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Vis regneark</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Angi forgrunnsfarge for cellen(e)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Angi forgrunnsfarge for cellen(e) i regnearket</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Angi bakgrunnsfarge for cellen(e)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Angi bakgrunnsfarge for cellen(e) i regnearket</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Regnearket støtter ikke valg av område ved innliming. Velg kun en celle.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Kopier og lim feilet</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>Aliaset inneholder ugyldige tegn!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Referer til celler med alias, for eksempel Spreadsheet.mitt_alias i stedet for Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Svart</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Hvit</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Rød</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Mørk rød</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Grønn</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Mørk grønn</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Blå</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Mørk blå</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Mørk cyan</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Mørk magenta</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Gul</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Mørk gul</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Grå</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Mørk grå</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Lys grå</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Egendefinert farge</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Skjema</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>&amp;Innhold:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Referer til celler med alias, for eksempel Spreadsheet.mitt_alias i stedet for Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Uten navn</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Sett inn rader</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Fjern rader</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Sett inn kolonner</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Fjern kolonner</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Egenskaper...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Regneark</translation>
    </message>
  </context>
</TS>
